@@ -66,6 +66,7 @@ constexpr bool IsNewline(const int ch) {
 }
 
 // True if can follow ch down to the end with possibly trailing whitespace
+// Does not set the state SCE_MARKDOWN_LINE_BEGIN as to allow further processing
 static bool FollowToLineEnd(const int ch, const int state, const Sci_PositionU endPos, StyleContext &sc) {
     Sci_Position i = 0;
     while (sc.GetRelative(++i) == ch)
@@ -74,9 +75,8 @@ static bool FollowToLineEnd(const int ch, const int state, const Sci_PositionU e
     while (IsASpaceOrTab(sc.GetRelative(i)) && sc.currentPos + i < endPos)
         ++i;
     if (IsNewline(sc.GetRelative(i)) || sc.currentPos + i == endPos) {
+        sc.SetState(state);
         sc.Forward(i);
-        sc.ChangeState(state);
-        sc.SetState(SCE_MARKDOWN_LINE_BEGIN);
         return true;
     }
     else return false;
@@ -126,15 +126,15 @@ static bool AtTermStart(StyleContext &sc) {
 
 static bool IsCompleteStyleRegion(StyleContext &sc, const char *token) {
     bool found = false;
-	const size_t start = strlen(token);
+    const size_t start = strlen(token);
     Sci_Position i = static_cast<Sci_Position>(start);
     while (!IsNewline(sc.GetRelative(i))) {
         // make sure an empty pair of single-char tokens doesn't match
         // with a longer token: {*}{*} != {**}
-	    if (sc.GetRelative(i) == *token && sc.GetRelative(i - 1) != *token) {
-		    found = start > 1U ? sc.GetRelative(i + 1) == token[1] : true;
-			break;
-		}
+        if (sc.GetRelative(i) == *token && sc.GetRelative(i - 1) != *token) {
+            found = start > 1U ? sc.GetRelative(i + 1) == token[1] : true;
+            break;
+        }
         i++;
     }
     return AtTermStart(sc) && found;
@@ -160,14 +160,14 @@ static bool IsValidHrule(const Sci_PositionU endPos, StyleContext &sc) {
             }
             else {
                 sc.SetState(SCE_MARKDOWN_DEFAULT);
-		return false;
+                return false;
             }
         }
     }
 }
 
 static void ColorizeMarkdownDoc(Sci_PositionU startPos, Sci_Position length, int initStyle,
-                               WordList **, Accessor &styler) {
+                                WordList **, Accessor &styler) {
     Sci_PositionU endPos = startPos + length;
     int precharCount = 0;
     bool isLinkNameDetecting = false;
@@ -176,6 +176,10 @@ static void ColorizeMarkdownDoc(Sci_PositionU startPos, Sci_Position length, int
     // in the default state.
     bool freezeCursor = false;
 
+    // property lexer.markdown.header.eolfill
+    //  Set to 1 to highlight all ATX header text.
+    bool headerEOLFill = styler.GetPropertyInt("lexer.markdown.header.eolfill", 0) == 1;
+
     StyleContext sc(startPos, static_cast<Sci_PositionU>(length), initStyle, styler);
 
     while (sc.More()) {
@@ -265,22 +269,45 @@ static void ColorizeMarkdownDoc(Sci_PositionU startPos, Sci_Position length, int
         }
         else if (sc.state == SCE_MARKDOWN_LINE_BEGIN) {
             // Header
-            if (sc.Match("######"))
-                SetStateAndZoom(SCE_MARKDOWN_HEADER6, 6, '#', sc);
-            else if (sc.Match("#####"))
-                SetStateAndZoom(SCE_MARKDOWN_HEADER5, 5, '#', sc);
-            else if (sc.Match("####"))
-                SetStateAndZoom(SCE_MARKDOWN_HEADER4, 4, '#', sc);
-            else if (sc.Match("###"))
-                SetStateAndZoom(SCE_MARKDOWN_HEADER3, 3, '#', sc);
-            else if (sc.Match("##"))
-                SetStateAndZoom(SCE_MARKDOWN_HEADER2, 2, '#', sc);
+            if (sc.Match("######")) {
+                if (headerEOLFill)
+                    sc.SetState(SCE_MARKDOWN_HEADER6);
+                else
+                    SetStateAndZoom(SCE_MARKDOWN_HEADER6, 6, '#', sc);
+            }
+            else if (sc.Match("#####")) {
+                if (headerEOLFill)
+                    sc.SetState(SCE_MARKDOWN_HEADER5);
+                else
+                    SetStateAndZoom(SCE_MARKDOWN_HEADER5, 5, '#', sc);
+            }
+            else if (sc.Match("####")) {
+                if (headerEOLFill)
+                    sc.SetState(SCE_MARKDOWN_HEADER4);
+                else
+                    SetStateAndZoom(SCE_MARKDOWN_HEADER4, 4, '#', sc);
+            }
+            else if (sc.Match("###")) {
+                if (headerEOLFill)
+                    sc.SetState(SCE_MARKDOWN_HEADER3);
+                else
+                    SetStateAndZoom(SCE_MARKDOWN_HEADER3, 3, '#', sc);
+            }
+            else if (sc.Match("##")) {
+                if (headerEOLFill)
+                    sc.SetState(SCE_MARKDOWN_HEADER2);
+                else
+                    SetStateAndZoom(SCE_MARKDOWN_HEADER2, 2, '#', sc);
+            }
             else if (sc.Match("#")) {
                 // Catch the special case of an unordered list
                 if (sc.chNext == '.' && IsASpaceOrTab(sc.GetRelative(2))) {
                     precharCount = 0;
                     sc.SetState(SCE_MARKDOWN_PRECHAR);
                 }
+                else if (headerEOLFill) {
+                    sc.SetState(SCE_MARKDOWN_HEADER1);
+                }
                 else
                     SetStateAndZoom(SCE_MARKDOWN_HEADER1, 1, '#', sc);
             }
@@ -292,14 +319,18 @@ static void ColorizeMarkdownDoc(Sci_PositionU startPos, Sci_Position length, int
                     sc.SetState(SCE_MARKDOWN_DEFAULT);
             }
             else if (sc.ch == '=') {
-                if (HasPrevLineContent(sc) && FollowToLineEnd('=', SCE_MARKDOWN_HEADER1, endPos, sc))
-                    ;
+                if (HasPrevLineContent(sc) && FollowToLineEnd('=', SCE_MARKDOWN_HEADER1, endPos, sc)) {
+                    if (!headerEOLFill)
+                        sc.SetState(SCE_MARKDOWN_LINE_BEGIN);
+                }
                 else
                     sc.SetState(SCE_MARKDOWN_DEFAULT);
             }
             else if (sc.ch == '-') {
-                if (HasPrevLineContent(sc) && FollowToLineEnd('-', SCE_MARKDOWN_HEADER2, endPos, sc))
-                    ;
+                if (HasPrevLineContent(sc) && FollowToLineEnd('-', SCE_MARKDOWN_HEADER2, endPos, sc)) {
+                    if (!headerEOLFill)
+                        sc.SetState(SCE_MARKDOWN_LINE_BEGIN);
+                }
                 else {
                     precharCount = 0;
                     sc.SetState(SCE_MARKDOWN_PRECHAR);
@@ -315,9 +346,15 @@ static void ColorizeMarkdownDoc(Sci_PositionU startPos, Sci_Position length, int
 
         // The header lasts until the newline
         else if (sc.state == SCE_MARKDOWN_HEADER1 || sc.state == SCE_MARKDOWN_HEADER2 ||
-                sc.state == SCE_MARKDOWN_HEADER3 || sc.state == SCE_MARKDOWN_HEADER4 ||
-                sc.state == SCE_MARKDOWN_HEADER5 || sc.state == SCE_MARKDOWN_HEADER6) {
-            if (IsNewline(sc.ch))
+                 sc.state == SCE_MARKDOWN_HEADER3 || sc.state == SCE_MARKDOWN_HEADER4 ||
+                 sc.state == SCE_MARKDOWN_HEADER5 || sc.state == SCE_MARKDOWN_HEADER6) {
+            if (headerEOLFill) {
+                if (sc.atLineStart) {
+                    sc.SetState(SCE_MARKDOWN_LINE_BEGIN);
+                    freezeCursor = true;
+                }
+            }
+            else if (IsNewline(sc.ch))
                 sc.SetState(SCE_MARKDOWN_LINE_BEGIN);
         }
 
@@ -367,21 +404,21 @@ static void ColorizeMarkdownDoc(Sci_PositionU startPos, Sci_Position length, int
         // Any link
         if (sc.state == SCE_MARKDOWN_LINK) {
             if (sc.Match("](") && sc.GetRelative(-1) != '\\') {
-              sc.Forward(2);
-              isLinkNameDetecting = true;
+                sc.Forward(2);
+                isLinkNameDetecting = true;
             }
             else if (sc.Match("]:") && sc.GetRelative(-1) != '\\') {
-              sc.Forward(2);
-              sc.SetState(SCE_MARKDOWN_DEFAULT);
+                sc.Forward(2);
+                sc.SetState(SCE_MARKDOWN_DEFAULT);
             }
             else if (!isLinkNameDetecting && sc.ch == ']' && sc.GetRelative(-1) != '\\') {
-              sc.Forward();
-              sc.SetState(SCE_MARKDOWN_DEFAULT);
+                sc.Forward();
+                sc.SetState(SCE_MARKDOWN_DEFAULT);
             }
             else if (isLinkNameDetecting && sc.ch == ')' && sc.GetRelative(-1) != '\\') {
-              sc.Forward();
-              sc.SetState(SCE_MARKDOWN_DEFAULT);
-              isLinkNameDetecting = false;
+                sc.Forward();
+                sc.SetState(SCE_MARKDOWN_DEFAULT);
+                isLinkNameDetecting = false;
             }
         }
 
@@ -393,11 +430,11 @@ static void ColorizeMarkdownDoc(Sci_PositionU startPos, Sci_Position length, int
             }
             // Links and Images
             if (sc.Match("![")) {
-              sc.SetState(SCE_MARKDOWN_LINK);
-              sc.Forward(1);
+                sc.SetState(SCE_MARKDOWN_LINK);
+                sc.Forward(1);
             }
             else if (sc.ch == '[' && sc.GetRelative(-1) != '\\') {
-              sc.SetState(SCE_MARKDOWN_LINK);
+                sc.SetState(SCE_MARKDOWN_LINK);
             }
             // Code - also a special case for alternate inside spacing
             else if (sc.Match("``") && sc.GetRelative(3) != ' ' && AtTermStart(sc)) {
@@ -412,7 +449,7 @@ static void ColorizeMarkdownDoc(Sci_PositionU startPos, Sci_Position length, int
             else if (sc.Match("**") && sc.GetRelative(2) != ' ' && IsCompleteStyleRegion(sc, "**")) {
                 sc.SetState(SCE_MARKDOWN_STRONG1);
                 sc.Forward();
-           }
+            }
             else if (sc.Match("__") && sc.GetRelative(2) != ' ' && IsCompleteStyleRegion(sc, "__")) {
                 sc.SetState(SCE_MARKDOWN_STRONG2);
                 sc.Forward();
@@ -420,12 +457,13 @@ static void ColorizeMarkdownDoc(Sci_PositionU startPos, Sci_Position length, int
             // Emphasis
             else if (sc.ch == '*' && sc.chNext != ' ' && IsCompleteStyleRegion(sc, "*")) {
                 sc.SetState(SCE_MARKDOWN_EM1);
-            } else if (sc.ch == '_' && sc.chNext != ' ' && IsCompleteStyleRegion(sc, "_")) {
+            }
+            else if (sc.ch == '_' && sc.chNext != ' ' && IsCompleteStyleRegion(sc, "_")) {
                 sc.SetState(SCE_MARKDOWN_EM2);
             }
             // Strikeout
             else if (sc.Match("~~") && !(sc.GetRelative(2) == '~' || sc.GetRelative(2) == ' ') &&
-                IsCompleteStyleRegion(sc, "~~")) {
+                     IsCompleteStyleRegion(sc, "~~")) {
                 sc.SetState(SCE_MARKDOWN_STRIKEOUT);
                 sc.Forward();
             }
