@@ -48,7 +48,11 @@ using namespace Lexilla;
 
 // Options used for LexerVisualProlog
 struct OptionsVisualProlog {
+    bool verbatimStrings;
+    bool backQuotedStrings;
     OptionsVisualProlog() {
+        verbatimStrings = true;
+        backQuotedStrings = false;
     }
 };
 
@@ -62,6 +66,10 @@ static const char *const visualPrologWordLists[] = {
 
 struct OptionSetVisualProlog : public OptionSet<OptionsVisualProlog> {
     OptionSetVisualProlog() {
+        DefineProperty("lexer.visualprolog.verbatim.strings", &OptionsVisualProlog::verbatimStrings,
+            "Set to 0 to disable highlighting verbatim strings using '@'.");
+        DefineProperty("lexer.visualprolog.backquoted.strings", &OptionsVisualProlog::backQuotedStrings,
+            "Set to 1 to enable using back quotes (``) to delimit strings.");
         DefineWordListSets(visualPrologWordLists);
     }
 };
@@ -148,12 +156,6 @@ Sci_Position SCI_METHOD LexerVisualProlog::WordListSet(int n, const char *wl) {
     return firstModification;
 }
 
-// Functor used to truncate history
-struct After {
-    Sci_Position line;
-    After(Sci_Position line_) : line(line_) {}
-};
-
 static bool isLowerLetter(int ch){
     return ccLl == CategoriseCharacter(ch);
 }
@@ -333,7 +335,7 @@ void SCI_METHOD LexerVisualProlog::Lex(Sci_PositionU startPos, Sci_Position leng
             }
             break;
         case SCE_VISUALPROLOG_COMMENT_LINE:
-            if (sc.atLineEnd) {
+            if (sc.MatchLineEnd()) {
                 int nextState = (nestLevel == 0) ? SCE_VISUALPROLOG_DEFAULT : SCE_VISUALPROLOG_COMMENT_BLOCK;
                 sc.SetState(nextState);
             } else if (sc.Match('@')) {
@@ -342,13 +344,13 @@ void SCI_METHOD LexerVisualProlog::Lex(Sci_PositionU startPos, Sci_Position leng
             }
             break;
         case SCE_VISUALPROLOG_COMMENT_KEY_ERROR:
-            if (!setDoxygen.Contains(sc.ch) || sc.atLineEnd) {
+            if (!setDoxygen.Contains(sc.ch) || sc.MatchLineEnd()) {
                 char s[1000];
                 sc.GetCurrent(s, sizeof(s));
                 if (docKeywords.InList(s+1)) {
                     sc.ChangeState(SCE_VISUALPROLOG_COMMENT_KEY);
                 }
-                if (SCE_VISUALPROLOG_COMMENT_LINE == styleBeforeDocKeyword && sc.atLineEnd) {
+                if (SCE_VISUALPROLOG_COMMENT_LINE == styleBeforeDocKeyword && sc.MatchLineEnd()) {
                     // end line comment
                     int nextState = (nestLevel == 0) ? SCE_VISUALPROLOG_DEFAULT : SCE_VISUALPROLOG_COMMENT_BLOCK;
                     sc.SetState(nextState);
@@ -372,7 +374,7 @@ void SCI_METHOD LexerVisualProlog::Lex(Sci_PositionU startPos, Sci_Position leng
             sc.SetState(SCE_VISUALPROLOG_STRING);
             // Falls through.
         case SCE_VISUALPROLOG_STRING:
-            if (sc.atLineEnd) {
+            if (sc.MatchLineEnd()) {
                 sc.SetState(SCE_VISUALPROLOG_STRING_EOL_OPEN);
             } else if (sc.Match(closingQuote)) {
                 sc.ForwardSetState(SCE_VISUALPROLOG_DEFAULT);
@@ -388,11 +390,13 @@ void SCI_METHOD LexerVisualProlog::Lex(Sci_PositionU startPos, Sci_Position leng
             break;
         case SCE_VISUALPROLOG_STRING_VERBATIM_SPECIAL:
         case SCE_VISUALPROLOG_STRING_VERBATIM_EOL:
+            if(sc.state == SCE_VISUALPROLOG_STRING_VERBATIM_EOL && !sc.atLineStart)
+                break;
             // return to SCE_VISUALPROLOG_STRING_VERBATIM and treat as such (fall-through)
             sc.SetState(SCE_VISUALPROLOG_STRING_VERBATIM);
             // Falls through.
         case SCE_VISUALPROLOG_STRING_VERBATIM:
-            if (sc.atLineEnd) {
+            if (sc.MatchLineEnd()) {
                 sc.SetState(SCE_VISUALPROLOG_STRING_VERBATIM_EOL);
             } else if (sc.Match(closingQuote)) {
                 if (closingQuote == sc.chNext) {
@@ -405,7 +409,7 @@ void SCI_METHOD LexerVisualProlog::Lex(Sci_PositionU startPos, Sci_Position leng
             break;
         }
 
-        if (sc.atLineEnd) {
+        if (sc.MatchLineEnd()) {
             // Update the line state, so it can be seen by next line
             int lineState = 0;
             if (SCE_VISUALPROLOG_STRING_VERBATIM_EOL == sc.state) {
@@ -419,7 +423,7 @@ void SCI_METHOD LexerVisualProlog::Lex(Sci_PositionU startPos, Sci_Position leng
 
         // Determine if a new state should be entered.
         if (sc.state == SCE_VISUALPROLOG_DEFAULT) {
-            if (sc.Match('@') && isOpenStringVerbatim(sc.chNext, closingQuote)) {
+            if (options.verbatimStrings && sc.Match('@') && isOpenStringVerbatim(sc.chNext, closingQuote)) {
                 sc.SetState(SCE_VISUALPROLOG_STRING_VERBATIM);
                 sc.Forward();
             } else if (IsADigit(sc.ch) || (sc.Match('.') && IsADigit(sc.chNext))) {
@@ -442,9 +446,13 @@ void SCI_METHOD LexerVisualProlog::Lex(Sci_PositionU startPos, Sci_Position leng
             } else if (sc.Match('"')) {
                 closingQuote = '"';
                 sc.SetState(SCE_VISUALPROLOG_STRING);
+            } else if (options.backQuotedStrings && sc.Match('`')) {
+                closingQuote = '`';
+                sc.SetState(SCE_VISUALPROLOG_STRING);
             } else if (sc.Match('#')) {
                 sc.SetState(SCE_VISUALPROLOG_KEY_DIRECTIVE);
-            } else if (isoperator(static_cast<char>(sc.ch)) || sc.Match('\\')) {
+            } else if (isoperator(static_cast<char>(sc.ch)) || sc.Match('\\') ||
+                (!options.verbatimStrings && sc.Match('@'))) {
                 sc.SetState(SCE_VISUALPROLOG_OPERATOR);
             }
         }
