@@ -257,7 +257,7 @@ void ScintillaEditBase::keyPressEvent(QKeyEvent *event)
 
 	bool consumed = false;
 	bool added = sqt->KeyDownWithModifiers(static_cast<Keys>(key),
-					       ScintillaQt::ModifierFlags(shift, ctrl, alt),
+					       ModifierFlags(shift, ctrl, alt),
 					       &consumed) != 0;
 	if (!consumed)
 		consumed = added;
@@ -331,7 +331,7 @@ void ScintillaEditBase::mousePressEvent(QMouseEvent *event)
 		bool alt   = QApplication::keyboardModifiers() & Qt::AltModifier;
 #endif
 
-		sqt->ButtonDownWithModifiers(pos, time.elapsed(), ScintillaQt::ModifierFlags(shift, ctrl, alt));
+		sqt->ButtonDownWithModifiers(pos, time.elapsed(), ModifierFlags(shift, ctrl, alt));
 	}
 
 	if (event->button() == Qt::RightButton) {
@@ -373,7 +373,7 @@ void ScintillaEditBase::mouseMoveEvent(QMouseEvent *event)
 	bool alt   = QApplication::keyboardModifiers() & Qt::AltModifier;
 #endif
 
-	const KeyMod modifiers = ScintillaQt::ModifierFlags(shift, ctrl, alt);
+	const KeyMod modifiers = ModifierFlags(shift, ctrl, alt);
 
 	sqt->ButtonMoveWithModifiers(pos, time.elapsed(), modifiers);
 }
@@ -826,5 +826,5 @@ KeyMod ScintillaEditBase::ModifiersOfKeyboard()
 	const bool ctrl  = QApplication::keyboardModifiers() & Qt::ControlModifier;
 	const bool alt   = QApplication::keyboardModifiers() & Qt::AltModifier;
 
-	return ScintillaQt::ModifierFlags(shift, ctrl, alt);
+	return ModifierFlags(shift, ctrl, alt);
 }
